---
description: ''
---

# Nuxt Setup

## Installation

::alert{type=warning}
Please install `pinia/nuxt` correctly. See [installation guidelines](https://pinia.vuejs.org/ssr/nuxt.html#installation).
::

::code-group
  ```bash [Yarn]
  yarn add pinia-orm @pinia-orm/nuxt
  ```
  ```bash [NPM]
  npm install @pinia-orm/nuxt --save
  ```
::

## Configuration

::alert{type="warning"}
If your using `Nuxt 2` and also using the `nanoid` package you gonna need to stick nanoid to version 3.3.4. This is related to https://github.com/ai/nanoid/issues/365
<br><br>
**E.g. yarn**

````json[package.json]
...
  "resolutions": {
    "nanoid": "3.3.4"
  }
...
````
::

::code-group
  ```ts{} [Nuxt 3]
  import { defineNuxtConfig } from 'nuxt3'
  
  export default defineNuxtConfig({
    modules: [
      '@pinia/nuxt', 
      '@pinia-orm/nuxt'
    ]
  })
  ```
  ```js{} [Nuxt 2]
  export default {
    buildModules: [
    '@nuxtjs/composition-api/module',
    '@pinia/nuxt'
    ],
    modules: ['@pinia-orm/nuxt'],
    // Related to https://github.com/nuxt/nuxt.js/issues/7822
    build: {
      transpile: [
        'pinia-orm'
      ]
    },
  }
  ```
::

## Usage on Nuxt 2
On Nuxt 2 with [nuxt composition api](https://composition-api.nuxtjs.org/) there is a drawback with the usage. You
always gonna need to pass the pinia instance to `useRepo` because otherwise on client side you will get an
error because the store is [called outside the store](https://pinia.vuejs.org/core-concepts/outside-component-usage.html).

In Nuxt 3 this problem somehow doesn't occur.

````ts{9}
import { defineComponent, useContext } from '@nuxtjs/composition-api'
import { useRepo } from 'pinia-orm'
import User from '~/models/User'

export default defineComponent({
  name: 'IndexPage',
  setup() {
    const { $pinia } = useContext()
    const userRepo = useRepo(User, $pinia)
    
    ...
  },
})

````
